"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
exports.ProfileService = void 0;
var path_1 = __importDefault(require("path"));
var ProfileService = /** @class */ (function () {
    function ProfileService(profiles) {
        this.profiles = {};
        for (var key in profiles) {
            if (Object.prototype.hasOwnProperty.call(profiles, key)) {
                var singleProfile = profiles[key];
                this._addProfile(key, path_1["default"].normalize(singleProfile.responseFileBasePath));
            }
        }
    }
    ProfileService.prototype.getAllProfiles = function () {
        return __assign({}, this.profiles);
    };
    ProfileService.prototype.getCurProfileBaseDir = function () {
        var curProfile = this.profiles[this.activeProfile];
        if (curProfile === undefined) {
            throw new Error('Could not get active profile (' + this.activeProfile + ') because no such profile is configured');
        }
        else {
            return curProfile.responseFileBasePath;
        }
    };
    ProfileService.prototype.readProfilesFromFileSystem = function (profileDirectory, fileRepository) {
        var _this = this;
        var _a;
        if (profileDirectory !== undefined) {
            var subDirectoryNames = (_a = fileRepository.getAllDirectoryNamesInDirSync(profileDirectory)) !== null && _a !== void 0 ? _a : [];
            subDirectoryNames.forEach(function (singleSubDirectoryName) {
                _this._addProfile(singleSubDirectoryName, path_1["default"].join(profileDirectory, singleSubDirectoryName));
            });
        }
    };
    ProfileService.prototype._addProfile = function (profileName, profileDirectory) {
        this.profiles[profileName] = {
            responseFileBasePath: profileDirectory
        };
    };
    ProfileService.prototype.assertExistsAndSetActiveProfile = function (newlyActiveProfile) {
        if (this.profiles[newlyActiveProfile] === undefined) {
            throw new Error('Could not set active profile (' + newlyActiveProfile + ') because no such profile is configured');
        }
        this.activeProfile = newlyActiveProfile;
    };
    ProfileService.prototype.getActiveProfile = function () {
        return this.activeProfile;
    };
    return ProfileService;
}());
exports.ProfileService = ProfileService;
